openCASCADE Engine
==================

Using the openCASCADE kernel instead of the built-in geometry kernel.  Models
can be built using constructive solid geometry, allowing for 2D and 3D polygon
boolean operations.

.. automodule:: pygmsh.occ

Geometry
--------
.. automodule:: pygmsh.occ.geometry
    :members:
    :undoc-members:
    :show-inheritance:

Ball
----
.. automodule:: pygmsh.occ.ball
    :members:
    :undoc-members:
    :show-inheritance:

Box
---
.. automodule:: pygmsh.occ.box
    :members:
    :undoc-members:
    :show-inheritance:

Cone
----
.. automodule:: pygmsh.occ.cone
    :members:
    :undoc-members:
    :show-inheritance:

Cylinder
--------
.. automodule:: pygmsh.occ.cylinder
    :members:
    :undoc-members:
    :show-inheritance:

Disk
----
.. automodule:: pygmsh.occ.disk
    :members:
    :undoc-members:
    :show-inheritance:

Rectangle
---------
.. automodule:: pygmsh.occ.rectangle
    :members:
    :undoc-members:
    :show-inheritance:

Torus
-----
.. automodule:: pygmsh.occ.torus
    :members:
    :undoc-members:
    :show-inheritance:

Wedge
-----
.. automodule:: pygmsh.occ.wedge
    :members:
    :undoc-members:
    :show-inheritance:
